package com.fractalite.hermes.teldar.services;

import java.text.ParseException;
import java.text.SimpleDateFormat;

import javax.xml.datatype.DatatypeConfigurationException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fractalite.hermes.teldar.Marshaller.MarshallingJAXB;
import com.fractalite.hermes.teldar.cfg.TeldarRouteBuilder;
import com.fractalite.models.commerce.QuoteTemplate;
import com.fractalite.models.travel.PaxType;
import com.fractalite.models.travel.Traveller;
import com.fractalite.models.travel.stay.HotelStay;
import com.fractalite.models.travel.stay.Occupancy2;
import com.fractalite.models.travel.stay.Room;
import com.gekko_holding.webservice.v2_4.AvailabilityCriteria;
import com.gekko_holding.webservice.v2_4.AvailabilityCriteria.RoomCriterias;
import com.gekko_holding.webservice.v2_4.Child;
import com.gekko_holding.webservice.v2_4.CustomerIdentification;
import com.gekko_holding.webservice.v2_4.DestinationCriteria;
import com.gekko_holding.webservice.v2_4.GeoCodeDestination;
import com.gekko_holding.webservice.v2_4.HotelAvailability;
import com.gekko_holding.webservice.v2_4.HotelCodeDestination;
import com.gekko_holding.webservice.v2_4.HotelCodeListDestination;
import com.gekko_holding.webservice.v2_4.RoomPlan;
import com.gekko_holding.webservice.v2_4.RoomPlan.Children;


public class SearchTeldarHotelPriceRequest extends TeldarServices {

	protected static Logger logger = LoggerFactory.getLogger(SearchTeldarHotelPriceRequest.class);

	@Override
	public void process(Exchange exchange)
			throws InvalidPayloadException, ParseException, DatatypeConfigurationException {

		 logger.trace("\n Invoking Teldarrrrrrrr SearchHotelsPriceRequest Processor.......");
		QuoteTemplate q = exchange.getIn().getMandatoryBody(QuoteTemplate.class);
		HotelStay hotelstay = q.getTrip().getContent(HotelStay.class).get(0);
		exchange.setProperty("hermesquery", q);
		HotelAvailability teldarReq = getList(hotelstay);
		logger.info("\n End teldargooooo SearchHotelsPriceRequest Processor......." + MarshallingJAXB.printXML(teldarReq));
		exchange.getIn().setBody(teldarReq, HotelAvailability.class);

	}

	public HotelAvailability getList(HotelStay hotelstay) throws ParseException, DatatypeConfigurationException {
		HotelAvailability hotelavailability = new HotelAvailability();
		CustomerIdentification customeridentification = new CustomerIdentification();

		customeridentification.setClientId(TeldarRouteBuilder.clientId);
		customeridentification.setPassword(TeldarRouteBuilder.password);
		customeridentification.setCustomerKey(TeldarRouteBuilder.customerKey);


		AvailabilityCriteria avaCriteria = new AvailabilityCriteria();
		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-mm-dd");

		hotelavailability.setIdentification(customeridentification);

		DestinationCriteria destinationcriteria = new DestinationCriteria();
	
		String desCode = hotelstay.getHotel().getAddress().getLocality().getCode();
		logger.info("loccccc" + desCode);
		if (desCode.contains("geo-")) {
			String[] geos = desCode.split("-");
			GeoCodeDestination geo = new GeoCodeDestination();
			geo.setLatitude(Double.parseDouble(geos[2]));
			geo.setLongitude(Double.parseDouble(geos[2]));
			geo.setRange(Double.parseDouble("2"));
			destinationcriteria.setGeoCode(geo);
			avaCriteria.setDestinationCriteria(destinationcriteria);

		} else {
			// Search By hotels codes

			HotelCodeListDestination hotelsList = new HotelCodeListDestination();
			int i=0;
			for (String hotelcodes : hotelstay.getGiatacode().getGekko_teldar()) {
				String[] codes = hotelcodes.split("-");
				String supplierCode = codes[0];
				String giataCode = codes[1];
				HotelCodeDestination hcode = new HotelCodeDestination();
				hcode.setCode(supplierCode);
				hotelsList.getHotel().add(hcode);
				
				if(i>298)
					break;
				i++;
				
			}

			destinationcriteria.setHotels(hotelsList);
			avaCriteria.setDestinationCriteria(destinationcriteria);
		}

		hotelavailability.setLanguage(language);
		avaCriteria.setCheckIn(hotelstay.getCheckin().toString());
		avaCriteria.setCheckOut(hotelstay.getCheckout().toString());
	
		RoomCriterias crit = new RoomCriterias();
		String roo = "";
		for (Room chambre : hotelstay.getRooms()) {

			Occupancy2 occupancy = new Occupancy2();
			RoomPlan roomoffers = new RoomPlan();

			int nbreOfAdult = 0;
		
			Children chlidren = new Children();
			
			for (Traveller traveller : chambre.getGuests()) {

				if (traveller.getClassification() == PaxType.ADULT)
					nbreOfAdult++;
				else if (traveller.getClassification() == PaxType.CHILD) {
		
					Child child = new Child();
					child.setAge(traveller.getAge().intValue());
					chlidren.getChild().add(child);
				}

			}
			occupancy.setAdults(nbreOfAdult);
			roomoffers.setRoomType(roo);
			roomoffers.setAdultsCount(nbreOfAdult);
			roomoffers.setChildren(chlidren);
			roomoffers.getRoomType();
			crit.getRoomPlan().add(roomoffers);

		}

		avaCriteria.setRoomCriterias(crit);

		hotelavailability.setAvailCriteria(avaCriteria);


		return hotelavailability;

	}

}
